@@ -235,26 +235,27 @@ globalVariables(c("DATE.IN", "DATE.OUT",
 #'  per patient for a specific medication.
 #'  \item \code{tot.dosage.changes} the total number of dosage changes per patient
 #'  for a specific medication.
-#'  }
-#'  @examples
-#'    event_durations <- compute_event_durations(disp.data = durcomp.dispensing,
-#'                                               presc.data = durcomp.prescribing,
-#'                                               hosp.data = durcomp.hospitalisation,
-#'                                               ID.colname = "ID",
-#'                                               presc.date.colname = "DATE.PRESC",
-#'                                               disp.date.colname = "DATE.DISP",
-#'                                               date.format = "%Y-%m-%d",
-#'                                               medication.class.colnames = c("ATC.CODE", "UNIT", "FORM"),
-#'                                               total.dose.colname = "TOTAL.DOSE",
-#'                                               presc.daily.dose.colname = "DAILY.DOSE",
-#'                                               presc.duration.colname = "PRESC.DURATION",
-#'                                               visit.colname = "VISIT",
-#'                                               force.init.presc = TRUE,
-#'                                               force.presc.renew = TRUE,
-#'                                               split.on.dosage.change = TRUE,
-#'                                               trt.interruption = "continue",
-#'                                               suppress.warnings = FALSE,
-#'                                               return.data.table = TRUE)
+#' }
+#' @examples
+#' event_durations <- compute_event_durations(disp.data = durcomp.dispensing[1:3,],
+#'                                            presc.data = durcomp.prescribing,
+#'                                            hosp.data = durcomp.hospitalisation,
+#'                                            ID.colname = "ID",
+#'                                            presc.date.colname = "DATE.PRESC",
+#'                                            disp.date.colname = "DATE.DISP",
+#'                                            date.format = "%Y-%m-%d",
+#'                                            medication.class.colnames = c("ATC.CODE",
+#'                                            "UNIT", "FORM"),
+#'                                            total.dose.colname = "TOTAL.DOSE",
+#'                                            presc.daily.dose.colname = "DAILY.DOSE",
+#'                                            presc.duration.colname = "PRESC.DURATION",
+#'                                            visit.colname = "VISIT",
+#'                                            force.init.presc = TRUE,
+#'                                            force.presc.renew = TRUE,
+#'                                            split.on.dosage.change = TRUE,
+#'                                            trt.interruption = "continue",
+#'                                            suppress.warnings = FALSE,
+#'                                            return.data.table = TRUE);
 #' @export
 compute_event_durations <- function(disp.data = NULL,
                                     presc.data = NULL,
@@ -334,9 +335,9 @@ compute_event_durations <- function(disp.data = NULL,
       if( !suppress.warnings ) warning(paste0("Column disp.date.colname='",disp.date.colname,"' must appear in the dispensing data!\n"));
       return (NULL);
     }
-    if( !is.na(medication.class.colnames) && !(medication.class.colnames %in% names(disp.data))  && !(medication.class.colnames %in% names(presc.data)) )
+    if( any(!is.na(medication.class.colnames) & !(medication.class.colnames %in% names(disp.data)) & !(medication.class.colnames %in% names(presc.data))) ) # deal with the possibility of multiple column names
     {
-      if( !suppress.warnings ) warning(paste0("Column medication.class.colnames='",medication.class.colnames,"' must appear in the dispensing and prescribing data!\n"));
+      if( !suppress.warnings ) warning(paste0("Column(s) medication.class.colnames=",paste0("'",medication.class.colnames,"'",collapse=",")," must appear in the dispensing and prescribing data!\n"));
       return (NULL);
     }
     if( !is.na(total.dose.colname) && !(total.dose.colname %in% names(disp.data)) )
@@ -1035,18 +1036,18 @@ compute_event_durations <- function(disp.data = NULL,
 #'  \item \code{first.disp} the date of the first dispensing event.
 #'  \item \code{time.to.initialization} the difference in days between the first
 #'  dispensing date and the  first prescription date.
-#'  }
-#'  @examples
-#'  time_init <- time_to_initiation(presc.data = durcomp.prescribing,
-#'                                  disp.data = durcomp.dispensing,
-#'                                  ID.colname = "ID",
-#'                                  presc.start.colname = "DATE.PRESC",
-#'                                  disp.date.colname = "DATE.DISP",
-#'                                  medication.class.colnames = c("ATC.CODE", "FORM", "UNIT"),
-#'                                  date.format = "%Y-%m-%d",
-#'                                  suppress.warnings = FALSE,
-#'                                  return.data.table = TRUE)
-#'  @export
+#' }
+#' @examples
+#' time_init <- time_to_initiation(presc.data = durcomp.prescribing,
+#'                                 disp.data = durcomp.dispensing,
+#'                                 ID.colname = "ID",
+#'                                 presc.start.colname = "DATE.PRESC",
+#'                                 disp.date.colname = "DATE.DISP",
+#'                                 medication.class.colnames = c("ATC.CODE", "FORM", "UNIT"),
+#'                                 date.format = "%Y-%m-%d",
+#'                                 suppress.warnings = FALSE,
+#'                                 return.data.table = TRUE);
+#' @export
 time_to_initiation <- function(presc.data = NULL,
                                disp.data = NULL,
                                ID.colname = NA,
@@ -1081,9 +1082,9 @@ time_to_initiation <- function(presc.data = NULL,
       return (NULL);
     }
 
-    if( !is.na(medication.class.colnames) && !(medication.class.colnames %in% names(disp.data)) && !(medication.class.colnames %in% names(presc.data)))
+    if( any(!is.na(medication.class.colnames) & !(medication.class.colnames %in% names(disp.data)) & !(medication.class.colnames %in% names(presc.data))) ) # deal with the possibility of multiple column names
     {
-      if( !suppress.warnings ) warning(paste0("Column(s) medication.class.colnames='",medication.class.colnames,"' must appear in the data!\n"));
+      if( !suppress.warnings ) warning(paste0("Column(s) medication.class.colnames=",paste0("'",medication.class.colnames,"'",collapse=",")," must appear in the dispensing and prescribing data!\n"));
       return (NULL);
     }
 
